#Load packages
library(baseline)
library(RColorBrewer)

#Read in data tables
wollemia <- read.table("Wollemia expt.txt", header = T, row.names = 1)
wollemia.info <- read.table("Wollemia expt meta.txt", header = T,  row.names = 1)

agathis <- read.table("Agathis experiment1.txt", header = T, row.names = 1)
agathis.info <- read.table("Agathis experiment1 meta.txt", header = T, row.names = 1)

wavenumbers <- as.numeric(unlist(strsplit(colnames(wollemia), "X"))[seq(2, 2*1764, by = 2)])

##Wollemia

#Baseline correct and standardise spectra
wollemia.base <- baseline(as.matrix(wollemia),
                     method='modpolyfit', deg=2)
wollemia.cor <- getCorrected(wollemia.base)
colnames(wollemia.cor) <- wavenumbers
wollemia.cor <- as.data.frame(wollemia.cor,
                              row.names = rownames(wollemia))

wollemia.cor.stand <- t(scale(t(wollemia.cor)))

#PCA
wollemia.cor.pca <- prcomp(wollemia.cor.stand)
#Importance of PCA axes
summary(wollemia.cor.pca)

par(mar = c(4,4,2,1)+0.1)
barplot(summary(wollemia.cor.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)

#Plot up
resins.cols <- brewer.pal(n = length(unique(wollemia.info$Treatment)), name = "Paired")
wollemia.cor.pca.scores <- as.data.frame(wollemia.cor.pca$x)

#PC1 vs PC2
plot(wollemia.cor.pca.scores[,1],
     wollemia.cor.pca.scores[,2],
     type = "n", xlab = "PC1 (63.50%)", ylab = "PC2 (19.03%)",
     las=1, 
     main = "")

points(wollemia.cor.pca.scores[wollemia.info$Treatment=="Cutoff",1],
       wollemia.cor.pca.scores[wollemia.info$Treatment=="Cutoff",2],
       pch=25, col = "black", bg = resins.cols[1], cex = 1.5)

points(wollemia.cor.pca.scores[wollemia.info$Treatment=="Branch",1],
       wollemia.cor.pca.scores[wollemia.info$Treatment=="Branch",2],
       pch=23, col = "black", bg = resins.cols[2], cex = 1.5)

points(wollemia.cor.pca.scores[wollemia.info$Treatment=="Burn",1],
       wollemia.cor.pca.scores[wollemia.info$Treatment=="Burn",2],
       pch=22, col = "black", bg = resins.cols[3], cex = 1.5)

points(wollemia.cor.pca.scores[wollemia.info$Treatment=="Insect",1],
       wollemia.cor.pca.scores[wollemia.info$Treatment=="Insect",2],
       pch=21, col = "black", bg = resins.cols[4], cex = 1.5)

points(wollemia.cor.pca.scores[wollemia.info$Treatment=="F_I",1],
       wollemia.cor.pca.scores[wollemia.info$Treatment=="F_I",2],
       pch=21, col = "black", bg = resins.cols[5], cex = 1.5)

points(wollemia.cor.pca.scores[wollemia.info$Treatment=="Drought",1],
       wollemia.cor.pca.scores[wollemia.info$Treatment=="Drought",2],
       pch=22, col = "black", bg = resins.cols[6], cex = 1.5)

points(wollemia.cor.pca.scores[wollemia.info$Treatment=="Control",1],
       wollemia.cor.pca.scores[wollemia.info$Treatment=="Control",2],
       pch=24, col = "black", bg = resins.cols[7], cex = 1.5)

legend ("topright", legend = c("Control", "Drought", "Flood+Insect", "Insect", "Burn", "Branch", "Cutoff"), 
        pch = c(24, 22, 21, 21, 22, 23, 25),
        col = "black", pt.bg = resins.cols[7:1],
        pt.cex = 1.5)

#Loadings
wollemia.cor.pca.loadings <- as.data.frame(wollemia.cor.pca$rotation)
plot(wavenumbers, wollemia.cor.pca.loadings[,1],
     type = "l", xlab = "Wavenumbers (cm-1)", ylab = "PC1 loadings",
     las=1, main = "", xlim = c(4000, 600))

plot(wavenumbers, wollemia.cor.pca.loadings[,2],
     type = "l", xlab = "Wavenumbers (cm-1)", ylab = "PC2 loadings",
     las=1, main = "", xlim = c(4000, 600))


#Cluster analysis
wollemia.cor.clust <- hclust(dist(wollemia.cor.stand), method = "average")
plot(wollemia.cor.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(wollemia.cor.clust, las = 1,
     main = "", xlab = "",
     ylab = "", sub = "",
     yaxt = "n", hang = -1, labels = wollemia.info$Treatment)

axis(2, lwd = 1, lwd.ticks = 1, tcl = -0.5,
     mgp = c(1.5, 1, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)


##Agathis
#Baseline correct and standardise
agathis.base <- baseline(as.matrix(agathis),
                          method='modpolyfit', deg=2)
agathis.cor <- getCorrected(agathis.base)
colnames(agathis.cor) <- wavenumbers
agathis.cor <- as.data.frame(agathis.cor,
                              row.names = rownames(agathis))

agathis.cor.stand <- t(scale(t(agathis.cor)))

#PCA
agathis.cor.pca <- prcomp(agathis.cor.stand)
#Importance of PCA axes
summary(agathis.cor.pca)

par(mar = c(4,4,2,1)+0.1)
barplot(summary(agathis.cor.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)
#85% on PC1, 10% on PC2

#Plot up
agathis.cor.pca.scores <- as.data.frame(agathis.cor.pca$x)

#PC1 vs PC2
plot(agathis.cor.pca.scores[,1],
     agathis.cor.pca.scores[,2],
     type = "n", xlab = "PC1 (84.59%)", ylab = "PC2 (9.86%)",
     las=1, 
     main = "")

points(agathis.cor.pca.scores[agathis.info$Treatment=="Cutoff",1],
       agathis.cor.pca.scores[agathis.info$Treatment=="Cutoff",2],
       pch=25, col = "black", bg = resins.cols[1], cex = 1.5)

points(agathis.cor.pca.scores[agathis.info$Treatment=="Branch",1],
       agathis.cor.pca.scores[agathis.info$Treatment=="Branch",2],
       pch=23, col = "black", bg = resins.cols[2], cex = 1.5)

points(agathis.cor.pca.scores[agathis.info$Treatment=="Burn",1],
       agathis.cor.pca.scores[agathis.info$Treatment=="Burn",2],
       pch=22, col = "black", bg = resins.cols[3], cex = 1.5)

points(agathis.cor.pca.scores[agathis.info$Treatment=="Insect",1],
       agathis.cor.pca.scores[agathis.info$Treatment=="Insect",2],
       pch=21, col = "black", bg = resins.cols[4], cex = 1.5)

legend ("bottomleft", legend = c("Insect", "Burn", "Branch", "Cutoff"), 
        pch = c(21, 22, 23, 25),
        col = "black", pt.bg = resins.cols[4:1],
        pt.cex = 1.5)


#Loadings
agathis.cor.pca.loadings <- as.data.frame(agathis.cor.pca$rotation)
plot(wavenumbers, agathis.cor.pca.loadings[,1],
     type = "l", xlab = "Wavenumbers (cm-1)", ylab = "PC1 loadings",
     las=1, main = "", xlim = c(4000, 600))

plot(wavenumbers, agathis.cor.pca.loadings[,2],
     type = "l", xlab = "Wavenumbers (cm-1)", ylab = "PC2 loadings",
     las=1, main = "", xlim = c(4000, 600))

#Cluster analysis
agathis.cor.clust <- hclust(dist(agathis.cor.stand), method = "average")
plot(agathis.cor.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

plot(agathis.cor.clust, las = 1,
     main = "", xlab = "",
     ylab = "", sub = "",
     yaxt = "n", hang = -1, labels = agathis.info$Treatment)

axis(2, lwd = 1, lwd.ticks = 1, tcl = -0.5,
     mgp = c(1.5, 1, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)


##Combined experiment analysis
woll.ag <- rbind(wollemia.cor.stand, agathis.cor.stand)
woll.ag.info <- rbind(wollemia.info, agathis.info)
woll.ag.info$Taxon <- c(rep("Wollemia", nrow(wollemia)),
                        rep("Agathis", nrow(agathis)))

#PCA
woll.ag.pca <- prcomp(woll.ag)
#Importance of PCA axes
summary(woll.ag.pca)

par(mar = c(4,4,2,1)+0.1)
barplot(summary(woll.ag.pca)[[6]][3,1:10],
        ylim = c(0, 1), las = 1, xlab = "PC axes",
        ylab = "Cumulative proportion of variance",
        main = "")
abline(h = 0.9, lty = 2)
#68% on PC1, 18% on PC2, 8% on PC3

#Plot up
woll.ag.pca.scores <- as.data.frame(woll.ag.pca$x)

#PC1 vs PC2
plot(woll.ag.pca.scores[,1],
     woll.ag.pca.scores[,2],
     type = "n", xlab = "PC1 (68.20%)", ylab = "PC2 (18.19%)",
     las=1, 
     main = "")

#Agathis
points(woll.ag.pca.scores[woll.ag.info$Taxon=="Agathis" & woll.ag.info$Treatment=="Cutoff",1],
       woll.ag.pca.scores[woll.ag.info$Taxon=="Agathis" & woll.ag.info$Treatment=="Cutoff",2],
       pch=25, col = resins.cols[1], bg = "white", cex = 1.5, lwd = 1.5)

points(woll.ag.pca.scores[woll.ag.info$Taxon=="Agathis" & woll.ag.info$Treatment=="Branch",1],
       woll.ag.pca.scores[woll.ag.info$Taxon=="Agathis" & woll.ag.info$Treatment=="Branch",2],
       pch=23, col = resins.cols[2], bg = "white", cex = 1.5, lwd = 1.5)

points(woll.ag.pca.scores[woll.ag.info$Taxon=="Agathis" & woll.ag.info$Treatment=="Burn",1],
       woll.ag.pca.scores[woll.ag.info$Taxon=="Agathis" & woll.ag.info$Treatment=="Burn",2],
       pch=22, col = resins.cols[3], bg = "white", cex = 1.5, lwd = 1.5)

points(woll.ag.pca.scores[woll.ag.info$Taxon=="Agathis" & woll.ag.info$Treatment=="Insect",1],
       woll.ag.pca.scores[woll.ag.info$Taxon=="Agathis" & woll.ag.info$Treatment=="Insect",2],
       pch=21, col = resins.cols[4], bg = "white", cex = 1.5, lwd = 1.5)

#Wollemia
points(woll.ag.pca.scores[woll.ag.info$Taxon=="Wollemia" & woll.ag.info$Treatment=="Cutoff",1],
       woll.ag.pca.scores[woll.ag.info$Taxon=="Wollemia" & woll.ag.info$Treatment=="Cutoff",2],
       pch=25, col = "black", bg = resins.cols[1], cex = 1.5)

points(woll.ag.pca.scores[woll.ag.info$Taxon=="Wollemia" & woll.ag.info$Treatment=="Branch",1],
       woll.ag.pca.scores[woll.ag.info$Taxon=="Wollemia" & woll.ag.info$Treatment=="Branch",2],
       pch=23, col = "black", bg = resins.cols[2], cex = 1.5)

points(woll.ag.pca.scores[woll.ag.info$Taxon=="Wollemia" & woll.ag.info$Treatment=="Burn",1],
       woll.ag.pca.scores[woll.ag.info$Taxon=="Wollemia" & woll.ag.info$Treatment=="Burn",2],
       pch=22, col = "black", bg = resins.cols[3], cex = 1.5)

points(woll.ag.pca.scores[woll.ag.info$Taxon=="Wollemia" & woll.ag.info$Treatment=="Insect",1],
       woll.ag.pca.scores[woll.ag.info$Taxon=="Wollemia" & woll.ag.info$Treatment=="Insect",2],
       pch=21, col = "black", bg = resins.cols[4], cex = 1.5)

points(woll.ag.pca.scores[woll.ag.info$Taxon=="Wollemia" & woll.ag.info$Treatment=="F_I",1],
       woll.ag.pca.scores[woll.ag.info$Taxon=="Wollemia" & woll.ag.info$Treatment=="F_I",2],
       pch=21, col = "black", bg = resins.cols[5], cex = 1.5)

points(woll.ag.pca.scores[woll.ag.info$Taxon=="Wollemia" & woll.ag.info$Treatment=="Drought",1],
       woll.ag.pca.scores[woll.ag.info$Taxon=="Wollemia" & woll.ag.info$Treatment=="Drought",2],
       pch=22, col = "black", bg = resins.cols[6], cex = 1.5)

points(woll.ag.pca.scores[woll.ag.info$Taxon=="Wollemia" & woll.ag.info$Treatment=="Control",1],
       woll.ag.pca.scores[woll.ag.info$Taxon=="Wollemia" & woll.ag.info$Treatment=="Control",2],
       pch=23, col = "black", bg = resins.cols[7], cex = 1.5)

#Loadings
woll.ag.pca.loadings <- as.data.frame(woll.ag.pca$rotation)
plot(wavenumbers, woll.ag.pca.loadings[,1],
     type = "l", xlab = "Wavenumbers (cm-1)", ylab = "PC1 loadings",
     las=1, main = "", xlim = c(4000, 600))

plot(wavenumbers, woll.ag.pca.loadings[,2],
     type = "l", xlab = "wavenumbers", ylab = "PC2 loadings",
     las=1, main = "", xlim = c(4000, 600))

#Cluster analysis
woll.ag.clust <- hclust(dist(woll.ag), method = "average")

#Plot with taxon labels
plot(woll.ag.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = woll.ag.info$Taxon)

axis(2, lwd = 1, lwd.ticks = 1, tcl = 0.3,
     mgp = c(1.5, 0.2, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)

#Plot with treatment labels
plot(woll.ag.clust, las = 1,
     main = "", xlab = "",
     ylab = "",
     yaxt = "n", hang = -1, labels = woll.ag.info$Treatment)

axis(2, lwd = 1, lwd.ticks = 1, tcl = -0.5,
     mgp = c(1.5, 1, 0),
     las = 1, line = 0.5)
title(ylab = "Euclidean distance", line = 3)


#Plot taxon mean spectra
woll.ag.taxonMeans <- aggregate(woll.ag, by = list(woll.ag.info$Taxon),
                                FUN = mean)
rownames(woll.ag.taxonMeans) <- woll.ag.taxonMeans[,1]
woll.ag.taxonMeans <- woll.ag.taxonMeans[,-1]

par(mfrow = c(1,1), oma = c(0,2,0,0), mar = c(5,1,2,1)+0.1)
plot(wavenumbers, woll.ag.taxonMeans[2,],
     type = "l", xlab = "Wavenumbers (cm-1)",
     ylab = "",
     las=1, main = "", yaxt = "n",
     xlim = c(4000, 600), ylim = c(-2, 12),
     col = "grey")

lines(wavenumbers, woll.ag.taxonMeans[1,]+7)

text(4000, 3, "Wollemia", pos = 4, col = "grey")
text(4000, 10, "Agathis", pos = 4)
mtext("Absorbance", side = 2, outer = T, line = 0)


#Taxon x treatment mean spectra
woll.ag.taxonTreatmentMeans <- aggregate(woll.ag,
                                         by = list(woll.ag.info$Treatment,
                                                   woll.ag.info$Taxon),
                                         FUN = mean)
rownames(woll.ag.taxonTreatmentMeans) <- paste(woll.ag.taxonTreatmentMeans[,2],
                                               woll.ag.taxonTreatmentMeans[,1],
                                               sep = ":")
woll.ag.taxonTreatmentMeans <- woll.ag.taxonTreatmentMeans[,-c(1,2)]

par(mfrow = c(1,2), oma = c(0,2,0,0), mar = c(5,1,2,1)+0.1)
#Agathis
plot(wavenumbers, woll.ag.taxonTreatmentMeans['Agathis:Cutoff',],
     type = "l", xlab = "Wavenumbers (cm-1)",
     ylab = "",
     las=1, main = "", yaxt = "n",
     xlim = c(4000, 600), ylim = c(-2, 47),
     col = resins.cols[1])

lines(wavenumbers, woll.ag.taxonTreatmentMeans['Agathis:Branch',]+7, col = resins.cols[2])
lines(wavenumbers, woll.ag.taxonTreatmentMeans['Agathis:Burn',]+14, col = resins.cols[3])
lines(wavenumbers, woll.ag.taxonTreatmentMeans['Agathis:Insect',]+21, col = resins.cols[4])

text(4000, 2, "Cutoff", pos = 4)
text(4000, 9, "Branch", pos = 4)
text(4000, 16, "Burn", pos = 4)
text(4000, 23, "Insect", pos = 4)

#Wollemia
plot(wavenumbers, woll.ag.taxonTreatmentMeans['Wollemia:Cutoff',],
     type = "l", xlab = "Wavenumbers (cm-1)",
     ylab = "",
     las=1, main = "", yaxt = "n",
     xlim = c(4000, 600), ylim = c(-2, 47),
     col = resins.cols[1])

lines(wavenumbers, woll.ag.taxonTreatmentMeans['Wollemia:Branch',]+7, col = resins.cols[2])
lines(wavenumbers, woll.ag.taxonTreatmentMeans['Wollemia:Burn',]+14, col = resins.cols[3])
lines(wavenumbers, woll.ag.taxonTreatmentMeans['Wollemia:Insect',]+21, col = resins.cols[4])
lines(wavenumbers, woll.ag.taxonTreatmentMeans['Wollemia:F_I',]+28, col = resins.cols[5])
lines(wavenumbers, woll.ag.taxonTreatmentMeans['Wollemia:Drought',]+35, col = resins.cols[6])
lines(wavenumbers, woll.ag.taxonTreatmentMeans['Wollemia:Control',]+42, col = resins.cols[7])

text(4000, 2, "Cutoff", pos = 4)
text(4000, 9, "Branch", pos = 4)
text(4000, 16, "Burn", pos = 4)
text(4000, 23, "Insect", pos = 4)
text(4000, 30, "Flood+Insect", pos = 4)
text(4000, 37, "Drought", pos = 4)
text(4000, 44, "Control", pos = 4)

mtext("Absorbance", side = 2, outer = T, line = 0)
